<?php

namespace Softwaretantra\Iksc\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Softwaretantra\Iksc\Http\Requests\TestikscRequest;
use Softwaretantra\Iksc\Models\Testiksc;

/**
 * Admin web controller class.
 */
class TestikscWorkflowController extends BaseController
{

    /**
     * Workflow controller function for testiksc.
     *
     * @param Model   $testiksc
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TestikscRequest $request, Testiksc $testiksc, $step)
    {

        try {

            $testiksc->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('iksc::testiksc.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/testiksc/testiksc/' . $testiksc->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/testiksc/testiksc/' . $testiksc->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for testiksc.
     *
     * @param Model   $testiksc
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Testiksc $testiksc, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $testiksc->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('iksc::testiksc.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('iksc::admin.testiksc.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('iksc::admin.testiksc.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('iksc::admin.testiksc.message', $data)->render();

        }

    }
}
