<?php

namespace Softwaretantra\Iksc\Policies;

use Litepie\User\Contracts\UserPolicy;
use Softwaretantra\Iksc\Models\Testiksc;

class TestikscPolicy
{

    /**
     * Determine if the given user can view the testiksc.
     *
     * @param UserPolicy $user
     * @param Testiksc $testiksc
     *
     * @return bool
     */
    public function view(UserPolicy $user, Testiksc $testiksc)
    {
        if ($user->canDo('iksc.testiksc.view') && $user->isAdmin()) {
            return true;
        }

        return $testiksc->user_id == user_id() && $testiksc->user_type == user_type();
    }

    /**
     * Determine if the given user can create a testiksc.
     *
     * @param UserPolicy $user
     * @param Testiksc $testiksc
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('iksc.testiksc.create');
    }

    /**
     * Determine if the given user can update the given testiksc.
     *
     * @param UserPolicy $user
     * @param Testiksc $testiksc
     *
     * @return bool
     */
    public function update(UserPolicy $user, Testiksc $testiksc)
    {
        if ($user->canDo('iksc.testiksc.edit') && $user->isAdmin()) {
            return true;
        }

        return $testiksc->user_id == user_id() && $testiksc->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given testiksc.
     *
     * @param UserPolicy $user
     * @param Testiksc $testiksc
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Testiksc $testiksc)
    {
        return $testiksc->user_id == user_id() && $testiksc->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given testiksc.
     *
     * @param UserPolicy $user
     * @param Testiksc $testiksc
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Testiksc $testiksc)
    {
        if ($user->canDo('iksc.testiksc.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given testiksc.
     *
     * @param UserPolicy $user
     * @param Testiksc $testiksc
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Testiksc $testiksc)
    {
        if ($user->canDo('iksc.testiksc.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
